@@ -5,14 +5,20 @@ import { VBoxModel } from '@jupyter-widgets/controls';
 
 import { MODULE_NAME, MODULE_VERSION } from '../version';
 
+/**
+ * The model for a panel.
+ */
 export class PanelModel extends VBoxModel {
-  defaults() {
+  /**
+   * The default attributes.
+   */
+  defaults(): any {
     return {
       ...super.defaults(),
       _model_name: PanelModel.model_name,
       _model_module: PanelModel.model_module,
       _model_module_version: PanelModel.model_module_version,
-      _view_name: null
+      _view_name: null,
     };
   }
 
